@@ -100,10 +100,11 @@ class StripeObject(dict):
     def __setitem__(self, k, v):
         if v == "":
             raise ValueError(
-                "You cannot set %s to an empty string. "
-                "We interpret empty strings as None in requests."
-                "You may set %s.%s = None to delete the property"
-                % (k, str(self), k)
+                "You cannot set %s to an empty string on this object. "
+                "The empty string is treated specially in our requests. "
+                "If you'd like to delete the property using the save() method on this object, you may set %s.%s = None. "
+                "Alternatively, you can pass %s='' to delete the property when using a resource method such as modify()."
+                % (k, str(self), k, k)
             )
 
         # Allows for unpickling in Python 3.x
@@ -246,6 +247,19 @@ class StripeObject(dict):
             response, api_key, self.stripe_version, self.stripe_account
         )
 
+    def request_stream(self, method, url, params=None, headers=None):
+        if params is None:
+            params = self._retrieve_params
+        requestor = api_requestor.APIRequestor(
+            key=self.api_key,
+            api_base=self.api_base(),
+            api_version=self.stripe_version,
+            account=self.stripe_account,
+        )
+        response, _ = requestor.request_stream(method, url, params, headers)
+
+        return response
+
     def __repr__(self):
         ident_parts = [type(self).__name__]
 
